@@ -1,9 +1,9 @@
 /*
  * libics: Image Cytometry Standard file reading and writing.
  *
- * Copyright 2015-2019, 2021, 2022:
+ * Copyright 2015-2019, 2021, 2022, 2024:
  *   Scientific Volume Imaging Holding B.V.
- *   Laapersveld 63, 1213 VB Hilversum, The Netherlands
+ *   Hilversum, The Netherlands.
  *   https://www.svi.nl
  *
  * Contact: libics@svi.nl
@@ -50,7 +50,7 @@ extern "C" {
 #endif
 
 /* Library versioning is in the form major, minor, patch: */
-#define ICSLIB_VERSION "1.6.6" /* also defined in configure.ac */
+#define ICSLIB_VERSION "1.6.8" /* also defined in configure.ac */
 
 #if defined(__WIN32__) && !defined(WIN32)
 #define WIN32
@@ -141,6 +141,8 @@ extern "C" {
 #define ICS_SENSOR_TYPE_RCM           "RescanConfMicr"
 /* This is a detector array microscope (AiryScan, NanoSpad): */
 #define ICS_SENSOR_TYPE_ARRDET        "ArrDetConfMicr"
+/* This is a STED detector array microscope (MatrixSTED): */
+#define ICS_SENSOR_TYPE_ARRDETSTED    "ArrDetSTEDMicr"
 /* This is a total internal reflection microsope (TIRF): */
 #define ICS_SENSOR_TYPE_TIRF          "TIRFMicr"
 /* This is a special type used for 3d SMLM calibration data: */
@@ -1006,3 +1008,4 @@ ICSEXPORT Ics_Error IcsReplaceHistoryStringI(ICS                 *ics,
 #endif
 
 #endif
+
